@@ -53,8 +53,7 @@ pub fn load_zymod_config_parser(filename: String, is_dry_run: i32, is_verbose: i
     let debug_to_log_level = log_level_converter(conf_info.debug as i8);
 
     let home_address = PathBuf::from(env!("HOME")).to_string_lossy().to_string();
-    let default_log_conf_file_address =
-        format!("{}/.var/log/zhiyan/mod_cpu.log", home_address);
+    let default_log_conf_file_address = format!("{}/.var/log/zhiyan/mod_cpu.log", home_address);
 
     let log_conf = build_log_config(
         default_log_conf_file_address,
